@@ -1,9 +1,15 @@
 #!/usr/bin/env python
 # flake8: noqa
 """Top-level module for flox ."""
+
 from . import cache
 from .aggregations import Aggregation, Scan  # noqa
-from .core import groupby_reduce, groupby_scan, rechunk_for_blockwise, rechunk_for_cohorts  # noqa
+from .core import (
+    groupby_reduce,
+    groupby_scan,
+    rechunk_for_blockwise,
+    rechunk_for_cohorts,
+)  # noqa
 
 
 def _get_version():
