@@ -1524,15 +1524,6 @@ def test_dtype(func, dtype, engine):
     assert actual.dtype == np.dtype("float64")
 
 
-@requires_dask
-def test_subset_blocks():
-    array = dask.array.random.random((120,), chunks=(4,))
-
-    blockid = (0, 3, 6, 9, 12, 15, 18, 21, 24, 27)
-    subset = subset_to_blocks(array, blockid)
-    assert subset.blocks.shape == (len(blockid),)
-
-
 @requires_dask
 @pytest.mark.parametrize(
     "flatblocks, expected",
@@ -1573,6 +1564,16 @@ def test_normalize_block_indexing_2d(flatblocks, expected):
     assert_equal_tuple(expected, actual)
 
 
+@requires_dask
+def test_subset_blocks():
+    array = dask.array.random.random((120,), chunks=(4,))
+
+    blockid = (0, 3, 6, 9, 12, 15, 18, 21, 24, 27)
+    subset = subset_to_blocks(array, blockid).to_array(array)
+    assert subset.blocks.shape == (len(blockid),)
+
+
+@pytest.mark.skip("temporarily removed this optimization")
 @requires_dask
 def test_subset_block_passthrough():
     from flox.core import identity
@@ -1580,12 +1581,12 @@ def test_subset_block_passthrough():
     # full slice pass through
     array = dask.array.ones((5,), chunks=(1,))
     expected = dask.array.map_blocks(identity, array)
-    subset = subset_to_blocks(array, np.arange(5))
+    subset = subset_to_blocks(array, np.arange(5)).to_array(array)
     assert subset.name == expected.name
 
     array = dask.array.ones((5, 5), chunks=1)
     expected = dask.array.map_blocks(identity, array)
-    subset = subset_to_blocks(array, np.arange(25))
+    subset = subset_to_blocks(array, np.arange(25)).to_array(array)
     assert subset.name == expected.name
 
 
@@ -1604,7 +1605,7 @@ def test_subset_block_passthrough():
 )
 def test_subset_block_2d(flatblocks, expectidx):
     array = dask.array.from_array(np.arange(25).reshape((5, 5)), chunks=1)
-    subset = subset_to_blocks(array, flatblocks)
+    subset = subset_to_blocks(array, flatblocks).to_array(array)
     assert len(subset.dask.layers) == 2
     assert_equal(subset, array.compute()[expectidx])
 
@@ -2006,3 +2007,32 @@ def test_blockwise_avoid_rechunk():
     actual, groups = groupby_reduce(array, by, func="first")
     assert_equal(groups, ["", "0", "1"])
     assert_equal(actual, np.array([0, 0, 0], dtype=np.int64))
+
+
+def test_datetime_minmax(engine):
+    # GH403
+    array = np.array([np.datetime64("2000-01-01"), np.datetime64("2000-01-02"), np.datetime64("2000-01-03")])
+    by = np.array([0, 0, 1])
+    actual, _ = flox.groupby_reduce(array, by, func="nanmin", engine=engine)
+    expected = array[[0, 2]]
+    assert_equal(expected, actual)
+
+    expected = array[[1, 2]]
+    actual, _ = flox.groupby_reduce(array, by, func="nanmax", engine=engine)
+    assert_equal(expected, actual)
+
+
+@pytest.mark.parametrize("func", ["first", "last", "nanfirst", "nanlast"])
+def test_datetime_timedelta_first_last(engine, func):
+    import flox
+
+    idx = 0 if "first" in func else -1
+
+    dt = pd.date_range("2001-01-01", freq="d", periods=5).values
+    by = np.ones(dt.shape, dtype=int)
+    actual, _ = flox.groupby_reduce(dt, by, func=func, engine=engine)
+    assert_equal(actual, dt[[idx]])
+
+    dt = dt - dt[0]
+    actual, _ = flox.groupby_reduce(dt, by, func=func, engine=engine)
+    assert_equal(actual, dt[[idx]])
